@@ -157,12 +157,7 @@ class SetProjectIcon(hook.Hook):
             try:
                 img = pilopen(Binary(icon.getvalue()))
             except IOError:
-                # XXX Here we should:
-                #raise ValueError('The icon file does not appear to be a valid image.')
-                # and add `icon` and `icon_format` to `ignored_relations` in
-                # test_forge to skip automatic population. Unfortunately, the
-                # latter does not work, so we simply:
-                return
+                raise ValueError('The icon file does not appear to be a known image format.')
             fmt = img.format
             project.cw_edited['icon_format'] = unicode('image/%s' % fmt.lower())
             img.thumbnail((50, 50), ANTIALIAS)
