@@ -7,7 +7,7 @@
 __docformat__ = "restructuredtext en"
 
 from cubicweb import NoSelectableObject
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubicweb.sobjects.notification import StatusChangeMixIn
 
 from cubes.tracker import sobjects as tracker
