@@ -1,15 +1,15 @@
 """some additional tabs for Ticket entities
 
 :organization: Logilab
-:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2006-2013 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 _ = unicode
 
+from cubicweb.predicates import one_line_rset, is_instance
 from cubicweb.web import component
 from cubicweb.web.views import tabs
-from cubicweb.selectors import one_line_rset, is_instance
 
 class TicketTestCardCtxComponent(component.RelatedObjectsCtxComponent):
     """display project's test cards"""
